@@ -8,7 +8,7 @@
 # License   : Revised BSD License
 # -----------------------------------------------------------------------------
 # Creation  : 26-Apr-2010
-# Last mod  : 23-Jul-2012
+# Last mod  : 30-Jul-2012
 # -----------------------------------------------------------------------------
 
 """
@@ -42,7 +42,7 @@ from __future__ import with_statement
 import base64, bz2, hashlib, os, random, sys, re, string, tempfile, subprocess, types, functools, StringIO
 import fabric, fabric.api, fabric.operations, fabric.context_managers
 
-VERSION         = "0.3.1"
+VERSION         = "0.3.2"
 RE_SPACES       = re.compile("[\s\t]+")
 MAC_EOL         = "\n"
 UNIX_EOL        = "\n"
@@ -62,7 +62,7 @@ DEFAULT_OPTIONS = dict(
 def sudo_password(password=None):
 	"""Sets the password for the sudo command."""
 	if password is None:
-		return fabric.api.env[SUDO_PASSWORD]
+		return fabric.api.env.get(SUDO_PASSWORD)
 	else:
 		if not password:
 			del fabric.api.env[SUDO_PASSWORD]
@@ -76,10 +76,7 @@ class __mode_switcher(object):
 	MODE_KEY   = None
 
 	def __init__( self ):
-		if self.MODE_KEY in fabric.api.env:
-			self.oldMode = fabric.api.env[self.MODE_KEY]
-		else:
-			self.oldMode = None
+		self.oldMode = fabric.api.env.get(self.MODE_KEY)
 		fabric.api.env[self.MODE_KEY] = self.MODE_VALUE
 
 	def __enter__(self):
@@ -120,7 +117,7 @@ def mode(key):
 
 def is_local():  return mode(MODE_LOCAL)
 def is_remote(): return not mode(MODE_LOCAL)
-def is_sudo():   return not mode(MODE_SUDO)
+def is_sudo():   return mode(MODE_SUDO)
 
 # =============================================================================
 #
@@ -143,12 +140,12 @@ def select_package( option=None ):
 # =============================================================================
 
 def run_local(command, sudo=False, shell=True, pty=True, combine_stderr=None):
-	'''
+	"""
 	Local implementation of fabric.api.run() using subprocess.
 	
 	Note: pty option exists for function signature compatibility and is
 	      ignored.
-	'''
+	"""
 	if combine_stderr is None: combine_stderr = fabric.api.env.combine_stderr
 	# TODO: Pass the SUDO_PASSWORD variable to the command here
 	if sudo: command = "sudo " + command
@@ -158,7 +155,7 @@ def run_local(command, sudo=False, shell=True, pty=True, combine_stderr=None):
 	# FIXME: Should stream the output, and only print it if fabric's properties allow it
 	# print out
 	# Wrap stdout string and add extra status attributes
-	result = fabric.operations._AttributeString(out)
+	result = fabric.operations._AttributeString(out.rstrip('\n'))
 	result.return_code = process.returncode
 	result.succeeded   = process.returncode == 0
 	result.failed      = not result.succeeded
@@ -859,12 +856,10 @@ def locale_check(locale):
 	return locale_data == locale
 
 def locale_ensure(locale):
-	if locale_check(locale):
-		return
-	with fabric.context_managers.settings(warn_only=True):
-		sudo("/usr/share/locales/install-language-pack %s" % (locale,))
-	sudo("dpkg-reconfigure locales")
-
+	if not locale_check(locale):
+		with fabric.context_managers.settings(warn_only=True):
+			sudo("/usr/share/locales/install-language-pack %s" % (locale,))
+		sudo("dpkg-reconfigure locales")
 
 # Sets up the default options so that @dispatch'ed functions work
 for option, value in DEFAULT_OPTIONS.items():
